Skip to contents

Wraps a causal graph object (e.g. a caugi::caugi graph, or a graph object from pcalg or bnlearn) and a Knowledge object into a Disco object, which is the output object of causal discovery methods used in causalDisco.

Usage

as_disco(graph, kn = knowledge(), class = "PDAG")

Arguments

graph

A causal graph object

kn

A Knowledge object. Default is an empty Knowledge object.

class

A string describing the graph class.

Value

A Disco object containing a caugi::caugi and a Knowledge object in a list.

Details

The conversion from any graph type to a caugi::caugi is handled by the caugi package.