disco_algs_return_doc_dag: Causal Discovery Algorithm Return Value DAG

disco_algs_return_doc_dagR Documentation

Causal Discovery Algorithm Return Value DAG

Description

Causal Discovery Algorithm Return Value DAG

Value

A function that takes a single argument data (a data frame). When called, this function returns a list containing:

  • knowledge A Knowledge object with the background knowledge used in the causal discovery algorithm. See knowledge() for how to construct it.

  • caugi A caugi::caugi object (of class DAG) representing the learned causal graph from the causal discovery algorithm.


causalDisco documentation built on April 13, 2026, 5:06 p.m.