disco_algs_return_doc_pag: Causal Discovery Algorithm Return Value PAG

disco_algs_return_doc_pagR Documentation

Causal Discovery Algorithm Return Value PAG

Description

Causal Discovery Algorithm Return Value PAG

Value

A function that takes a single argument data (a data frame). When called, this function returns a list containing:

  • knowledge A Knowledge object with the background knowledge used in the causal discovery algorithm. See knowledge() for how to construct it.

  • caugi A caugi::caugi object representing the learned causal graph. This graph is a PAG (Partial Ancestral Graph), but since PAGs are not yet natively supported in caugi, it is currently stored with class UNKNOWN.


causalDisco documentation built on April 13, 2026, 5:06 p.m.