disco_algs_return_doc_pdag: Causal Discovery Algorithm Return Value PDAG

disco_algs_return_doc_pdagR Documentation

Causal Discovery Algorithm Return Value PDAG

Description

Causal Discovery Algorithm Return Value PDAG

Value

A function that takes a single argument data (a data frame). When called, this function returns a list containing:

  • knowledge A Knowledge object with the background knowledge used in the causal discovery algorithm. See knowledge() for how to construct it.

  • caugi A caugi::caugi object (of class PDAG) representing the learned causal graph from the causal discovery algorithm.


causalDisco documentation built on April 13, 2026, 5:06 p.m.