Learn R Programming

causalDisco (version 1.0.1)

disco_note: Disco Recommendation Note

Description

Disco Recommendation Note

Arguments

Recommendation

While it is possible to call the function returned directly with a data frame, we recommend using disco(). This provides a consistent interface and handles knowledge integration.