View source: R/extend-causaldisco-algs.R
| distribute_engine_args | R Documentation |
This function checks the provided arguments against the expected arguments for the specified engine and algorithm, and distributes them appropriately to the search object. It ensures that the arguments are valid for the given engine and algorithm, and then sets them on the search object.
distribute_engine_args(search, args, engine, alg)
search |
R6 object, either |
args |
List of arguments to distribute |
engine |
Engine identifier, either "tetrad", "bnlearn", "pcalg", or "causalDisco" |
alg |
Algorithm name |
Other Extending causalDisco:
list_registered_tetrad_algorithms(),
make_method(),
make_runner(),
new_disco_method(),
register_tetrad_algorithm(),
reset_tetrad_alg_registry()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.