View source: R/install-tetrad.R
| install_tetrad | R Documentation |
Downloads and installs the Tetrad GUI JAR file from
Maven Central.
It downloads the specified version of the Tetrad GUI JAR and its corresponding SHA256 checksum file, and saves them
in the specified directory (or cache). If the JAR already exists and force = FALSE, it will skip downloading.
install_tetrad(
version = getOption("causalDisco.tetrad.version"),
dir = NULL,
force = FALSE,
quiet = FALSE,
temp_dir = FALSE
)
version |
Character; the Tetrad version to install. Default is
|
dir |
Character; the directory where the JAR should be installed. If
|
force |
Logical; if |
quiet |
Logical; if |
temp_dir |
Logical; if |
In line with CRAN policies this function will only
return messages and not throw warnings/errors if the installation fails (e.g. due to no internet connection),
and return NULL.
Invisibly returns the full path to the installed Tetrad JAR.
## Not run:
# Install default version in cache directory
install_tetrad()
# Install a specific version and force re-download
install_tetrad(version = "7.6.10", force = TRUE)
# Install in a temporary directory
install_tetrad(temp_dir = TRUE)
# Install quietly (suppress messages)
install_tetrad(quiet = TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.