Returns the names of all custom engines registered via
register_engine() (in addition to the built-in engines "bnlearn",
"causalDisco", "pcalg", and "tetrad", which are always available).
Returns the names of all custom engines registered via
register_engine() (in addition to the built-in engines "bnlearn",
"causalDisco", "pcalg", and "tetrad", which are always available).