- model
tpdag, tskeleton, tpag, or tamat object to plot.
- xjit
How much should nodes within a period be jittered horizontally.
- yjit
Vertical distance between nodes within a period.
- markperiods
If TRUE, gray boxes are drawn behind each period.
- xpgap
Horizontal gap between different periods.
- annotateEdges
If TRUE, add a text annotation to edges. If annotationlabels
are supplied, these labels will be used. Otherwise, the value in the inputted adjacency matrix corresponding
to the edge will be used. Cannot be used for tpag
input objects (or ag amat types).
- addAxis
If TRUE, a horizontal axis with period labels are added.
- varLabels
Optional labels for nodes (variables). Should be given as a named list, where
the name is the variable name, and the entry is the label, e.g. list(vname = "Label for vname").
- periodLabels
Optional labels for periods. Should be given as a named list, where
the name is the period name (as stored in the tamat), and the entry is the label,
e.g. list(periodname = "Label for period").
- annotationLabels
Optional labels for edge annotations. Only used if annotateEdges = TRUE.
Should be given as a named list, where the name is the edge annotation (as stored in the tamat),
and the entry is the label, e.g. list(h = "High").
- clipboard
If TRUE, the tikz code is not printed, but instead copied to the clipboard,
so it can easily be pasted into a Latex document.
- rawout
If TRUE, the tikz code is only returned as a character vector.
- colorAnnotate
Named list of colors to use to mark edge annotations instead of labels. This
overrules annotateEdges and both are not available at the same time. The list should be given with
annotations as names and colors as entries, e.g. list(h = "blue"). Cannot be used for tpag
input objects (or ag amat types).
- bendedges
If TRUE, all edges are bend 10 degrees to the right, thereby avoiding having edges exactly on
top of each other.