Skip to contents

Registers a new Tetrad algorithm by adding it to the internal registry. The setup_fun() should be a function that takes the same arguments as the runner function for the algorithm and sets up the Tetrad search object accordingly. This allows you to extend the set of Tetrad algorithms that can be used with causalDisco.

Usage

register_tetrad_algorithm(name, setup_fun)

Arguments

name

Algorithm name (string)

setup_fun

A function that sets up the Tetrad search object for the algorithm. It should take the same arguments as the runner function for the algorithm.