| disco_algs_return_doc_pag | R Documentation |
Causal Discovery Algorithm Return Value PAG
A function that takes a single argument data (a data frame). When called,
this function returns a list containing:
knowledge A Knowledge object with the background knowledge
used in the causal discovery algorithm. See knowledge() for how to construct it.
caugi A caugi::caugi object representing the learned causal graph.
This graph is a PAG (Partial Ancestral Graph), but since PAGs are not yet
natively supported in caugi, it is currently stored with class UNKNOWN.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.