Distribute and Validate Engine Arguments
Source:R/extend-causaldisco-algs.R
distribute_engine_args.RdThis function checks the provided arguments against the expected arguments for the specified engine and algorithm, and distributes them appropriately to the search object. It ensures that the arguments are valid for the given engine and algorithm, and then sets them on the search object.
See also
Other Extending causalDisco:
new_disco_method(),
register_tetrad_algorithm(),
reset_tetrad_alg_registry()