This function checks the provided arguments against the expected arguments for the specified engine and algorithm, and distributes them appropriately to the search object. It ensures that the arguments are valid for the given engine and algorithm, and then sets them on the search object.
distribute_engine_args(search, args, engine, alg)R6 object, either TetradSearch, BnlearnSearch, PcalgSearch, or CausalDiscoSearch.
List of arguments to distribute
Engine identifier, either "tetrad", "bnlearn", "pcalg", or "causalDisco"
Algorithm name
Other Extending causalDisco:
new_disco_method(),
register_tetrad_algorithm(),
reset_tetrad_alg_registry()