| fci | R Documentation |
Run the Fast Causal Inference algorithm for causal discovery using one of several engines.
fci(engine = c("tetrad", "pcalg"), test, alpha = 0.05, ...)
engine |
Character; which engine to use. Must be one of:
|
test |
Character; name of the conditionalâindependence test. |
alpha |
Numeric; significance level for the CI tests. |
... |
Additional arguments passed to the chosen engine (e.g. test or algorithm parameters). |
For specific details on the supported tests and parameters for each engine, see:
TetradSearch for Tetrad,
PcalgSearch for pcalg.
While it is possible to call the function returned directly with a data frame,
we recommend using disco(). This provides a consistent interface and handles knowledge
integration.
A function that takes a single argument data (a data frame). When called,
this function returns a list containing:
knowledge A Knowledge object with the background knowledge
used in the causal discovery algorithm. See knowledge() for how to construct it.
caugi A caugi::caugi object representing the learned causal graph.
This graph is a PAG (Partial Ancestral Graph), but since PAGs are not yet
natively supported in caugi, it is currently stored with class UNKNOWN.
Spirtes, P., Meek, C., & Richardson, T. (1995, August). Causal inference in the presence of latent variables and selection bias. In Proceedings of the Eleventh conference on Uncertainty in artificial intelligence (pp. 499-506).
Other causal discovery algorithms:
boss(),
boss_fci(),
ges(),
gfci(),
grasp(),
grasp_fci(),
gs(),
iamb-family,
pc(),
sp_fci(),
tfci(),
tges(),
tpc()
data(tpc_example)
# Recommended path using disco()
fci_pcalg <- fci(engine = "pcalg", test = "fisher_z", alpha = 0.05)
disco(tpc_example, fci_pcalg)
# or using fci_pcalg directly
fci_pcalg(tpc_example)
# With all algorithm arguments specified
fci_pcalg <- fci(
engine = "pcalg",
test = "fisher_z",
alpha = 0.05,
skel.method = "original",
type = "anytime",
fixedGaps = NULL,
fixedEdges = NULL,
NAdelete = FALSE,
m.max = 10,
pdsep.max = 2,
rules = c(rep(TRUE, 9), FALSE),
doPdsep = FALSE,
biCC = TRUE,
conservative = TRUE,
maj.rule = FALSE,
numCores = 1,
selectionBias = FALSE,
jci = "1",
verbose = FALSE
)
disco(tpc_example, fci_pcalg)
#### Using tetrad engine with tier knowledge ####
# Requires Tetrad to be installed
if (verify_tetrad()$installed && verify_tetrad()$java_ok) {
kn <- knowledge(
tpc_example,
tier(
child ~ tidyselect::starts_with("child"),
youth ~ tidyselect::starts_with("youth"),
oldage ~ tidyselect::starts_with("oldage")
)
)
# Recommended path using disco()
fci_tetrad <- fci(engine = "tetrad", test = "fisher_z", alpha = 0.05)
disco(tpc_example, fci_tetrad, knowledge = kn)
# or using fci_tetrad directly
fci_tetrad <- fci_tetrad |> set_knowledge(kn)
fci_tetrad(tpc_example)
}
# With all algorithm arguments specified
if (verify_tetrad()$installed && verify_tetrad()$java_ok) {
fci_tetrad <- fci(
engine = "tetrad",
test = "fisher_z",
alpha = 0.05,
complete_rule_set_used = FALSE,
max_disc_path_length = 4,
depth = 10,
stable_fas = FALSE,
guarantee_pag = TRUE
)
disco(tpc_example, fci_tetrad)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.