| gs | R Documentation |
Run the Grow-Shrink algorithm for causal discovery using one of several engines.
gs(engine = c("bnlearn"), test, alpha = 0.05, ...)
engine |
Character; which engine to use. Must be one of:
|
test |
Character; name of the conditionalâindependence test. |
alpha |
Numeric; significance level for the CI tests. |
... |
Additional arguments passed to the chosen engine (e.g. test or algorithm parameters). |
For specific details on the supported tests and parameters for each engine, see:
BnlearnSearch for bnlearn.
While it is possible to call the function returned directly with a data frame,
we recommend using disco(). This provides a consistent interface and handles knowledge
integration.
A function that takes a single argument data (a data frame). When called,
this function returns a list containing:
knowledge A Knowledge object with the background knowledge
used in the causal discovery algorithm. See knowledge() for how to construct it.
caugi A caugi::caugi object (of class PDAG) representing the learned causal graph
from the causal discovery algorithm.
Margaritis, D., Thrun, S.: Bayesian network induction via local neighborhoods. Tech. rep., DTIC Document (2000).
Other causal discovery algorithms:
boss(),
boss_fci(),
fci(),
ges(),
gfci(),
grasp(),
grasp_fci(),
iamb-family,
pc(),
sp_fci(),
tfci(),
tges(),
tpc()
data(tpc_example)
kn <- knowledge(
tpc_example,
starts_with("child") %-->% starts_with("youth")
)
# Recommended path using disco()
gs_bnlearn <- gs(
engine = "bnlearn",
test = "fisher_z",
alpha = 0.05
)
disco(tpc_example, gs_bnlearn, knowledge = kn)
# or using gs_bnlearn directly
gs_bnlearn <- gs_bnlearn |> set_knowledge(kn)
gs_bnlearn(tpc_example)
# With all algorithm arguments specified
gs_bnlearn <- gs(
engine = "bnlearn",
test = "fisher_z",
alpha = 0.05,
max.sx = 2,
debug = FALSE,
undirected = TRUE
)
disco(tpc_example, gs_bnlearn)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.