| iamb-family | R Documentation |
Functions for causal discovery using variants of the Incremental Association algorithm:
iamb: Incremental Association (IAMB)
inter_iamb: Interleaved Incremental Association (Inter-IAMB)
iamb_fdr: Incremental Association with FDR (IAMB-FDR)
fast_iamb: Fast Incremental Association (Fast-IAMB)
iamb(engine = c("bnlearn"), test, alpha = 0.05, ...)
iamb_fdr(engine = c("bnlearn"), test, alpha = 0.05, ...)
fast_iamb(engine = c("bnlearn"), test, alpha = 0.05, ...)
inter_iamb(engine = c("bnlearn"), test, alpha = 0.05, ...)
engine |
Character; which engine to use. Must be one of:
|
test |
Character; name of the conditionalâindependence test. |
alpha |
Numeric; significance level for the CI tests. |
... |
Additional arguments passed to the chosen engine (e.g., test or algorithm parameters). |
Each function supports the same engines and parameters. For details on tests and parameters for each engine, see:
BnlearnSearch for bnlearn.
While it is possible to call the function returned directly with a data frame,
we recommend using disco(). This provides a consistent interface and handles knowledge
integration.
A function that takes a single argument data (a data frame). When called,
this function returns a list containing:
knowledge A Knowledge object with the background knowledge
used in the causal discovery algorithm. See knowledge() for how to construct it.
caugi A caugi::caugi object representing the learned causal graph.
This graph is a PAG (Partial Ancestral Graph), but since PAGs are not yet
natively supported in caugi, it is currently stored with class UNKNOWN.
I. Tsamardinos, C. F. Aliferis, and A. Statnikov. Algorithms for large scale Markov blanket discovery. In Proceedings of the Sixteenth International Florida Artificial Intelligence Research Society Conference, pages 376-381. AAAI Press, 2003.
Other causal discovery algorithms:
boss(),
boss_fci(),
fci(),
ges(),
gfci(),
grasp(),
grasp_fci(),
gs(),
pc(),
sp_fci(),
tfci(),
tges(),
tpc()
data(tpc_example)
kn <- knowledge(
tpc_example,
starts_with("child") %-->% starts_with("youth")
)
##### iamb #####
# Recommended path using disco()
iamb_bnlearn <- iamb(engine = "bnlearn", test = "fisher_z", alpha = 0.05)
disco(tpc_example, iamb_bnlearn, knowledge = kn)
# or using iamb_bnlearn directly
iamb_bnlearn <- iamb_bnlearn |> set_knowledge(kn)
iamb_bnlearn(tpc_example)
# With all algorithm arguments specified
iamb_bnlearn <- iamb(
engine = "bnlearn",
test = "fisher_z",
alpha = 0.05,
max.sx = 2,
debug = FALSE,
undirected = TRUE
)
disco(tpc_example, iamb_bnlearn)
##### iamb_fdr #####
iamb_fdr_bnlearn <- iamb_fdr(
engine = "bnlearn",
test = "fisher_z",
alpha = 0.05
)
disco(tpc_example, iamb_fdr_bnlearn, knowledge = kn)
##### fast_iamb #####
fast_iamb_bnlearn <- fast_iamb(
engine = "bnlearn",
test = "fisher_z",
alpha = 0.05
)
disco(tpc_example, fast_iamb_bnlearn, knowledge = kn)
#### inter_iamb #####
inter_iamb_bnlearn <- inter_iamb(
engine = "bnlearn",
test = "fisher_z",
alpha = 0.05
)
disco(tpc_example, inter_iamb_bnlearn, knowledge = kn)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.