| make_method | R Documentation |
Constructs a new causal discovery method that can be used
with the disco() framework. Users can provide an engine, engine-specific
functions, and optional test and alpha parameters.
make_method(
method_name,
engine,
engine_fns,
test = NULL,
alpha = NULL,
score = NULL,
graph_class,
...
)
method_name |
Character. The name of the method to create. |
engine |
Character. The engine to use. Must be one of the names of
|
engine_fns |
Named list of functions. Each element corresponds to an engine and is a function that implements the causal discovery algorithm. |
test |
Optional. A test statistic to pass to the engine function. |
alpha |
Optional. A significance level to pass to the engine function. |
score |
Optional. A score to pass to the engine function. |
graph_class |
Character. The graph class that this method produces. |
... |
Additional arguments passed to the engine function. |
A disco_method object with attributes engine and graph_class.
Other Extending causalDisco:
distribute_engine_args(),
list_registered_tetrad_algorithms(),
make_runner(),
new_disco_method(),
register_tetrad_algorithm(),
reset_tetrad_alg_registry()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.