Constructs a runner function for a specific causal discovery engine and algorithm. This allows users to support new algorithms.
Arguments
- engine
Character. The engine to use. Options include
"causalDisco","pcalg","bnlearn","tetrad", or the name of any engine added viaregister_engine().- alg
Character. The algorithm name.
- test
Optional. A test statistic to pass to the engine.
- alpha
Optional. Significance level to pass to the engine.
- score
Optional. A scoring function for score-based methods.
- ...
Additional arguments passed to the engine-specific runner.
Value
An object representing a configured runner for the chosen engine. The type depends on the engine.