Skip to contents

[Experimental]

Constructs a runner function for a specific causal discovery engine and algorithm. This allows users to support new algorithms.

Usage

make_runner(
  engine,
  alg,
  test = NULL,
  alpha = NULL,
  score = NULL,
  ...,
  directed_as_undirected_knowledge = FALSE
)

Arguments

engine

Character. The engine to use. Options include "causalDisco", "pcalg", "bnlearn", "tetrad".

alg

Character. The algorithm name.

test

Optional. A test statistic to pass to the engine.

alpha

Optional. Significance level to pass to the engine.

score

Optional. A scoring function for score-based methods.

...

Additional arguments passed to the engine-specific runner.

directed_as_undirected_knowledge

Logical. Used internally for pcalg.

Value

An object representing a configured runner for the chosen engine. The type depends on the engine.