| make_runner | R Documentation |
Constructs a runner function for a specific causal discovery engine and algorithm. This allows users to support new algorithms.
make_runner(
engine,
alg,
test = NULL,
alpha = NULL,
score = NULL,
...,
directed_as_undirected_knowledge = FALSE
)
engine |
Character. The engine to use. Options include |
alg |
Character. The algorithm name. |
test |
Optional. A test statistic to pass to the engine. |
alpha |
Optional. Significance level to pass to the engine. |
score |
Optional. A scoring function for score-based methods. |
... |
Additional arguments passed to the engine-specific runner. |
directed_as_undirected_knowledge |
Logical. Used internally for pcalg. |
An object representing a configured runner for the chosen engine. The type depends on the engine.
Other Extending causalDisco:
distribute_engine_args(),
list_registered_tetrad_algorithms(),
make_method(),
new_disco_method(),
register_tetrad_algorithm(),
reset_tetrad_alg_registry()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.