powered by
A dataset combining continuous and categorical variables. The first three variables are replaced with categorical versions from cat_data.
cat_data
mix_data
A data.frame with 1000 rows and 5 variables.
Categorical, from cat_data$X1.
cat_data$X1
Categorical, from cat_data$X2.
cat_data$X2
Categorical, from cat_data$X3.
cat_data$X3
Numeric, same as num_data$Z.
num_data$Z
Numeric, same as num_data$Y.
num_data$Y
The R code used to generate this dataset is as follows:
data(num_data) data(cat_data) mix_data <- num_data mix_data$X1 <- cat_data$X1 mix_data$X2 <- cat_data$X2 mix_data$X3 <- cat_data$X3
num_data, cat_data
data(mix_data) head(mix_data)
Run the code above in your browser using DataLab