This function allows you to create a new causal discovery method that can be used with the disco() function.
You provide a builder function that constructs a runner object, along with metadata about the algorithm, and it
returns a closure that can be called with a data frame to perform causal discovery and return a caugi::caugi object.
Value
A function of class "disco_method" that takes a single argument
data (a data frame) and returns a caugi::caugi object.
See also
Other Extending causalDisco:
distribute_engine_args(),
register_tetrad_algorithm(),
reset_tetrad_alg_registry()