View source: R/extend-causaldisco-algs.R
| new_disco_method | R Documentation |
This function allows you to create a new causal discovery method that can be used with the disco() function.
You provide a builder function that constructs a runner object, along with metadata about the algorithm, and it
returns a closure that can be called with a data frame to perform causal discovery and return a caugi::caugi object.
new_disco_method(builder, name, engine, graph_class)
builder |
A function returning a runner |
name |
Algorithm name |
engine |
Engine identifier |
graph_class |
Output graph class |
A function of class "disco_method" that takes a single argument
data (a data frame) and returns a caugi::caugi object.
Other Extending causalDisco:
distribute_engine_args(),
list_registered_tetrad_algorithms(),
make_method(),
make_runner(),
register_tetrad_algorithm(),
reset_tetrad_alg_registry()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.