Learn R Programming

causalDisco (version 1.0.1)

new_disco_method: Add a New causalDisco Method

Description

This function allows you to create a new causal discovery method that can be used with the disco() function. You provide a builder function that constructs a runner object, along with metadata about the algorithm, and it returns a closure that can be called with a data frame to perform causal discovery and return a caugi::caugi object.

Usage

new_disco_method(builder, name, engine, graph_class)

Value

A function of class "disco_method" that takes a single argument data (a data frame) and returns a caugi::caugi object.

Arguments

builder

A function returning a runner

name

Algorithm name

engine

Engine identifier

graph_class

Output graph class

See Also

Other Extending causalDisco: distribute_engine_args(), register_tetrad_algorithm(), reset_tetrad_alg_registry()