Registers a new Tetrad algorithm by adding it to the internal registry. The setup_fun() should be a function that
takes the same arguments as the runner function for the algorithm and sets up the Tetrad search object accordingly.
This allows you to extend the set of Tetrad algorithms that can be used with causalDisco.
register_tetrad_algorithm(name, setup_fun)Algorithm name (string)
A function that sets up the Tetrad search object for the algorithm. It should take the same arguments as the runner function for the algorithm.
Other Extending causalDisco:
distribute_engine_args(),
new_disco_method(),
reset_tetrad_alg_registry()